@@ -39,6 +39,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include "gdm-xerrors.h"
 #include "gdm-signal-handler.h"
 #include "gdm-log.h"
 #include "gdm-common.h"
@@ -197,6 +198,7 @@ main (int    argc,
                 goto out;
         }
 
+        gdm_xerrors_init ();
         gdm_log_init ();
 
         settings = gdm_settings_new ();
@@ -205,7 +207,7 @@ main (int    argc,
                 exit (1);
         }
 
-        if (! gdm_settings_direct_init (settings, GDMCONFDIR "/gdm.schemas", "/")) {
+        if (! gdm_settings_direct_init (settings, DATADIR "/gdm/gdm.schemas", "/")) {
                 g_warning ("Unable to initialize settings");
                 exit (1);
         }
